@@ -9,7 +9,7 @@ use File::Spec;
 use File::Find;
 use Cwd ();
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 sub new {
   my ($class, $root, $opts) = @_;
@@ -223,9 +223,17 @@ sub _examine_pkg {
           return;            # don't screw up 02packages
       }
   }
+  return unless $self->_version_ok($pp);
+
   $pp;
 }
 
+sub _version_ok {
+  my ($self, $pp) = @_;
+  return if length($pp->{version} || 0) > 16;
+  return 1
+}
+
 # from PAUSE::dist;
 sub _filter_pms {
   my($self) = @_;
